@@ -24,7 +24,6 @@
 #include <glib/gi18n.h>
 #include <gmodule.h>
 
-#include "ephy-search-engine-listbox.h"
 #include "ephy-search-engine-manager.h"
 
 #include "ephy-embed-shell.h"
@@ -383,14 +382,6 @@ on_remove_button_clicked_cb (EphySearchEngineRow *row,
   ephy_search_engine_manager_delete_engine (row->manager, row->engine);
 }
 
-static void
-ephy_search_engine_row_finalize (GObject *object)
-{
-  /* EphySearchEngineRow *self = (EphySearchEngineRow *)object; */
-
-  G_OBJECT_CLASS (ephy_search_engine_row_parent_class)->finalize (object);
-}
-
 static void
 ephy_search_engine_row_set_property (GObject      *object,
                                      guint         prop_id,
@@ -441,8 +432,8 @@ on_ephy_search_engine_row_constructed (GObject *object)
    * properties bindings that involve the root widget (the <template> root one).
    */
   g_object_bind_property (self->name_entry, "text",
-                          HDY_PREFERENCES_ROW (self), "title",
-                          G_BINDING_SYNC_CREATE | G_BINDING_DEFAULT);
+                          self, "title",
+                          G_BINDING_SYNC_CREATE);
 
   gtk_entry_set_text (GTK_ENTRY (self->address_entry),
                       ephy_search_engine_get_url (self->engine));
@@ -468,7 +459,6 @@ ephy_search_engine_row_class_init (EphySearchEngineRowClass *klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-  object_class->finalize = ephy_search_engine_row_finalize;
   object_class->set_property = ephy_search_engine_row_set_property;
   object_class->constructed = on_ephy_search_engine_row_constructed;
 
